@@ -15,7 +15,7 @@
 #include <QMimeData>
 #include <QStandardPaths>
 
-using namespace KIdentityManagement;
+using namespace KIdentityManagementCore;
 
 QTEST_GUILESS_MAIN(IdentityTester)
 
@@ -228,7 +228,7 @@ void IdentityTester::test_Aliases()
     QCOMPARE(i1.emailAliases().size(), 2);
 
     KConfig testConfig(QStringLiteral("test"));
-    KConfigGroup testGroup(&testConfig, "testGroup");
+    KConfigGroup testGroup(&testConfig, QStringLiteral("testGroup"));
     i1.writeConfig(testGroup);
     i1.readConfig(testGroup);
     QCOMPARE(i1.emailAliases().size(), 2);
@@ -303,3 +303,5 @@ void IdentityTester::test_migration()
         QVERIFY(compareIdentities(i2, identity));
     }
 }
+
+#include "moc_identitytest.cpp"
