@@ -24,7 +24,7 @@
 #include <KPIMTextEdit/RichTextComposer>
 #include <KPIMTextEdit/RichTextComposerControler>
 #include <KPIMTextEdit/RichTextComposerImages>
-using namespace KIdentityManagement;
+using namespace KIdentityManagementCore;
 using namespace KPIMTextEdit;
 
 QTEST_MAIN(SignatureTester)
@@ -214,7 +214,7 @@ void SignatureTester::testImages()
     QString configPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QStringLiteral("/signaturetest");
     QDir().mkpath(configPath);
     KConfig config(configPath);
-    KConfigGroup group1 = config.group("Signature1");
+    KConfigGroup group1 = config.group(QStringLiteral("Signature1"));
 
     MySignature sig;
     sig.setEnabledSignature(true);
@@ -289,3 +289,5 @@ void SignatureTester::testLinebreaks()
     QEXPECT_FAIL("", "This test is probably bogus, since Qt doesn't seem to produce HTML like this anymore.", Continue);
     QCOMPARE(edit.toPlainText(), QStringLiteral("-- \nHans Mustermann\nMusterstr. 42"));
 }
+
+#include "moc_signaturetest.cpp"
